Learn R Programming

waspr (version 1.0.1)

print.wasp: Print posterior summaries for the Wasserstein barycenter of subset posteriors

Description

Prints selected output from a Bayesian circular mixed-effects model.

Usage

# S3 method for wasp
print(x, ...)

Value

A print of posterior summaries for the Wasserstein barycenter of subset posteriors

Arguments

x

a wasp object obtained from the function wasp().

...

further arguments passed to or from other methods.

Examples

Run this code
library(waspr)
out <- wasp(pois_logistic,
            par.names = c("beta_s", "alpha_l", "beta_l",
                          "baseline_sigma", "baseline_mu",
                          "correlation", "sigma_s", "sigma_l"))
print(out)

Run the code above in your browser using DataLab